@@ -33,6 +33,28 @@ namespace sigc
 namespace internal
 {
 
+// Conversion between different types of function pointers with
+// reinterpret_cast can make gcc8 print a warning.
+// https://github.com/libsigcplusplus/libsigcplusplus/issues/1
+// https://github.com/libsigcplusplus/libsigcplusplus/issues/8
+/** Returns the supplied function pointer, cast to a pointer to another function type.
+ *
+ * When a single reinterpret_cast between function pointer types causes a
+ * compiler warning or error, this function may work.
+ *
+ * Qualify calls with namespace names: sigc::internal::function_pointer_cast<>().
+ * If you don't, indirect calls from another library that also contains a
+ * function_pointer_cast<>() (perhaps glibmm), can be ambiguous due to ADL
+ * (argument-dependent lookup).
+ */
+template <typename T_out, typename T_in>
+inline T_out function_pointer_cast(T_in in)
+{
+  // The double reinterpret_cast suppresses a warning from gcc8 with the
+  // -Wcast-function-type option.
+  return reinterpret_cast<T_out>(reinterpret_cast<void (*)()>(in));
+}
+
 /** A typed slot_rep.
  * A typed slot_rep holds a functor that can be invoked from
  * slot::operator()(). visit_each() is used to visit the functor's
@@ -134,7 +156,7 @@ struct slot_call
   /** Forms a function pointer from call_it().
    * @return A function pointer formed from call_it().
    */
-  static hook address() { return reinterpret_cast<hook>(&call_it); }
+  static hook address() { return sigc::internal::function_pointer_cast<hook>(&call_it); }
 };
 
 } /* namespace internal */
@@ -168,8 +190,10 @@ struct slot_call
  *
  * @ingroup slot
  */
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 template <typename T_return, typename... T_arg>
 class slot;
+#endif // DOXYGEN_SHOULD_SKIP_THIS
 
 template <typename T_return, typename... T_arg>
 class slot<T_return(T_arg...)> : public slot_base
@@ -192,7 +216,7 @@ public:
   inline T_return operator()(type_trait_take_t<T_arg>... a) const
   {
     if (!empty() && !blocked()) {
-      return std::invoke(reinterpret_cast<call_type>(slot_base::rep_->call_), slot_base::rep_, a...);
+      return std::invoke(sigc::internal::function_pointer_cast<call_type>(slot_base::rep_->call_), slot_base::rep_, a...);
     }
 
     return T_return();
