@@ -5,10 +5,6 @@
 #include "testutilities.h"
 #include <sigc++/adaptors/bind.h>
 #include <sigc++/functors/slot.h>
-#include <sstream>
-#include <string>
-#include <functional> //For std::ref().
-#include <cstdlib>
 
 namespace
 {
@@ -22,7 +18,7 @@ struct foo
   int operator()(int i)
   {
     result_stream << "foo(int " << i << ") ";
-    return i > 0;
+    return static_cast<int>(i > 0);
   }
 
   int operator()(int i, int j)
